@@ -366,7 +366,7 @@ int
 device_removable( const char* device )
 {
     struct sysfs_device *dev;
-    static char* hotplug_buses[] = { "usb", "ieee1394", "mmc", NULL };
+    static char* hotplug_buses[] = { "usb", "ieee1394", "mmc", "pcmcia", NULL };
     int removable;
     char blockdevpath[PATH_MAX];
 
@@ -402,7 +402,7 @@ device_whitelisted( const char* device )
     regex_t re;
     regmatch_t match[3];
     int result;
-    const char* whitelist_regex = "^[[:space:]]*([a-zA-Z0-9/_+.-]+)[[:space:]]*(#.*)?$";
+    const char* whitelist_regex = "^[[:space:]]*([[:alnum:]/_+.\-]+)[[:space:]]*(#.*)?$";
 
     fwl = fopen( WHITELIST, "r" );
     if( !fwl )
